ReportBro Lib
=================

ReportBro is a library to generate PDF and XLSX reports. Report templates can be created
with `ReportBro Designer <https://github.com/jobsta/reportbro-designer>`_,
a Javascript Plugin which can be integrated in your web application.

See the ReportBro project website on https://www.reportbro.com for full documentation and demos.

Features
--------

* Python 2.7 and Python >= 3.5 support
* Generate pdf and xlsx reports
* Supports (repeating) header and footer
* Allows predefined and own page formats
* Use text, line, images, barcodes and tables, page breaks
* Text and element styling
* Evaluate expressions, define conditional styles, format parameters

Installation
------------

.. code:: shell

    pip install reportbro-lib

Go to https://www.reportbro.com/doc/api#lib-arguments for more information on configuration and usage.

Python Coding Style
-------------------

The `PEP 8 (Python Enhancement Proposal) <https://www.python.org/dev/peps/pep-0008/>`_
standard is used which is the de-facto code style guide for Python. An easy-to-read version
of PEP 8 can be found at https://pep8.org

For pull requests the same coding styles should be used.

License
-------

- Commercial license

If you want to use ReportBro to develop commercial applications and projects, the Commercial license is the appropriate license. With this license, your source code is kept proprietary. Purchase a ReportBro Commercial license at https://www.reportbro.com/license/index.

- Open-source license

If you are creating an open-source application under a license compatible with the `GNU AGPL license v3 <https://www.gnu.org/licenses/agpl-3.0.html>`_, you may use ReportBro under the terms of the AGPLv3.

Read more about ReportBro's license options at https://www.reportbro.com/license/index.
